/* -*-c-*-
 *
 * $Id: ec-raw.h,v 1.2 2004/04/08 01:36:15 mdw Exp $
 *
 * Raw formatting of elliptic curve points
 *
 * (c) 2004 Straylight/Edgeware
 */

/*----- Licensing notice --------------------------------------------------*
 *
 * This file is part of Catacomb.
 *
 * Catacomb is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * Catacomb is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with Catacomb; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 */

#ifndef CATACOMB_EC_RAW_H
#define CATACOMB_EC_RAW_H

#ifdef __cplusplus
  extern "C" {
#endif

/*----- Header files ------------------------------------------------------*/

#ifndef CATACOMB_BUF_H
#  include "buf.h"
#endif

#ifndef CATACOMB_EC_H
#  include "ec.h"
#endif

/*----- Data formatting ---------------------------------------------------*/

/* --- @ec_putraw@ --- *
 *
 * Arguments:	@ec_curve *c@ = elliptic curve
 *		@buf *b@ = pointer to a buffer
 *		@const ec *p@ = an elliptic curve point
 *
 * Returns:	Zero on success, nonzero on failure.
 *
 * Use:		Puts an elliptic curve point to the given buffer using the
 *		standard uncompressed format described in P1383 and SEC1.
 *		We don't do point compression.
 */

extern int ec_putraw(ec_curve */*c*/, buf */*b*/, const ec */*p*/);

/* --- @ec_getraw@ --- *
 *
 * Arguments:	@ec_curve *c@ = elliptic curve
 *		@buf *b@ = pointer to a buffer
 *		@ec *d@ = an elliptic curve point
 *
 * Returns:	Zero on success, nonzero on failure.
 *
 * Use:		Reads an elliptic curve point from the given buffer using the
 *		standard uncompressed format described in P1383 and SEC1.
 *		We don't do point compression.
 */

extern int ec_getraw(ec_curve */*c*/, buf */*b*/, ec */*d*/);

/*----- That's all, folks -------------------------------------------------*/

#ifdef __cplusplus
  }
#endif

#endif
